@@ -1,16 +1,7 @@
-import pathlib
 from typing import Union
 
-from localtileserver.server import TileClient
-
-
-def get_data_path(name):
-    dirname = pathlib.Path(__file__).parent
-    return dirname / "data" / name
-
-
-def get_pine_gulch_url():
-    return "https://opendata.digitalglobe.com/events/california-fire-2020/pre-event/2018-02-16/pine-gulch-fire20/1030010076004E00.tif"
+from localtileserver.client import TileClient
+from localtileserver.tileserver import get_data_path, get_pine_gulch_url, get_sf_bay_url
 
 
 def get_blue_marble(port: Union[int, str] = "default", debug: bool = False):
@@ -41,3 +32,13 @@ def get_bahamas(port: Union[int, str] = "default", debug: bool = False):
 def get_pine_gulch(port: Union[int, str] = "default", debug: bool = False):
     path = get_pine_gulch_url()
     return TileClient(path, port=port, debug=debug)
+
+
+def get_landsat(port: Union[int, str] = "default", debug: bool = False):
+    path = get_data_path("landsat.tif")
+    return TileClient(path, port=port, debug=debug)
+
+
+def get_san_francisco(port: Union[int, str] = "default", debug: bool = False):
+    path = get_sf_bay_url()
+    return TileClient(path, port=port, debug=debug)
